/*
**  ConsoleWindow.m
**
**  Copyright (c) 2001-2004
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "ConsoleWindow.h"

#include "Constants.h"

@implementation ConsoleWindow

//
//
//
- (void) dealloc
{
  NSDebugLog(@"ConsoleWindow: -dealloc");
  
  RELEASE(tasksTableView);
  RELEASE(tasksScrollView);
  RELEASE(messagesTableView);
  RELEASE(messagesScrollView);
  RELEASE(toggle);
  RELEASE(delete);
  RELEASE(suspend);
  RELEASE(save);

  [super dealloc];
}


//
//
//
- (void) layoutWindow
{
  NSTableColumn *statusColumn, *activityColumn, *dateColumn, *messageColumn, *operationColumn;
  NSTabViewItem *tabViewItem1, *tabViewItem2;
  NSTabView *tabView;
  NSView *view;
  NSBox *box;
  

  //
  // Our tab view
  //
  tabView = [[NSTabView alloc] initWithFrame: NSMakeRect(0,0,500,278)];
  [tabView setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];

  //
  // Our first tabview
  //
  view = [[NSView alloc] initWithFrame: NSMakeRect(0,35,500,280)];
  [view setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];

  //
  // Our first box - current tasks
  //
  box = [[NSBox alloc] initWithFrame: NSMakeRect(5,5,490,265)];
  [box setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable|NSViewMaxYMargin];
  [box setTitlePosition: NSAtTop];
  [box setTitle: _(@"Current Activities")];
  [box setBorderType: NSGrooveBorder];
  [view addSubview: box];
  
  activityColumn = [[NSTableColumn alloc] initWithIdentifier: @"Activity"];
  [activityColumn setEditable: NO];
  [activityColumn setResizable: YES];
  [[activityColumn headerCell] setStringValue: _(@"Activity")];
  [activityColumn setMinWidth: 100];
  [[activityColumn headerCell] setAlignment: NSLeftTextAlignment];
  
  statusColumn = [[NSTableColumn alloc] initWithIdentifier: @"Status"];
  [statusColumn setEditable: NO];
  [statusColumn setResizable: YES];
  [[statusColumn headerCell] setStringValue: _(@"Status")];
  [statusColumn setMinWidth: 240];
  [statusColumn setMaxWidth: 240];
  [[statusColumn headerCell] setAlignment: NSLeftTextAlignment];

  operationColumn = [[NSTableColumn alloc] initWithIdentifier: @"Operation"];
  [operationColumn setEditable: YES];
  [operationColumn setResizable: YES];
  [[operationColumn headerCell] setStringValue: _(@"Operation")];
  [operationColumn setMinWidth: 100];
  [operationColumn setMaxWidth: 100];
  [[operationColumn headerCell] setAlignment: NSLeftTextAlignment];

  tasksScrollView = [[NSScrollView alloc] initWithFrame: NSMakeRect(5,35,470,200)];

  tasksTableView = [[NSTableView alloc] initWithFrame: [[tasksScrollView contentView] frame]];
  [tasksTableView setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];
  [tasksTableView setDrawsGrid: NO];
  [tasksTableView setAllowsColumnSelection: NO];
  [tasksTableView setAllowsColumnReordering: NO];
  [tasksTableView setAllowsColumnResizing: YES];
  [tasksTableView setAllowsEmptySelection: YES];
  [tasksTableView setAllowsMultipleSelection: NO];
  [tasksTableView addTableColumn: activityColumn];
  [tasksTableView addTableColumn: statusColumn];
  [tasksTableView addTableColumn: operationColumn];
  [tasksTableView setAutoresizesAllColumnsToFit: YES];
  [tasksTableView sizeLastColumnToFit];
  [tasksTableView setDataSource: [self windowController]];
  [tasksTableView setDelegate: [self windowController]];
  RELEASE(activityColumn);
  RELEASE(statusColumn);
  RELEASE(operationColumn);

  [tasksScrollView setDocumentView: tasksTableView];
  [tasksScrollView setHasHorizontalScroller: NO];
  [tasksScrollView setHasVerticalScroller: YES];
  [tasksScrollView setBorderType: NSBezelBorder];
  [tasksScrollView setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];

  [box addSubview: tasksScrollView];

  toggle = [[NSButton alloc] initWithFrame: NSMakeRect(5,0,70,ButtonHeight)];
  [toggle setButtonType: NSMomentaryPushButton];
  [toggle setTitle: _(@"Stop")];
  [box addSubview: toggle];

  delete = [[NSButton alloc] initWithFrame: NSMakeRect(80,0,70,ButtonHeight)];
  [delete setButtonType: NSMomentaryPushButton];
  [delete setTitle: _(@"Delete")];
  [delete setTarget: self];
  [delete setAction: @selector(deleteClicked:)];
  [box addSubview: delete];

  suspend = [[NSButton alloc] initWithFrame: NSMakeRect(155,0,70,ButtonHeight)];
  [suspend setButtonType: NSMomentaryPushButton];
  [suspend setTitle: _(@"Suspend")];
  [suspend setTarget: self];
  [suspend setAction: @selector(suspendClicked:)];
  [box addSubview: suspend];

  save = [[NSButton alloc] initWithFrame: NSMakeRect(375,0,100,ButtonHeight)];
  [save setAutoresizingMask: NSViewMinXMargin];
  [save setButtonType: NSMomentaryPushButton];
  [save setTitle: _(@"Save in Drafts")];
  [save setTarget: self];
  [save setAction: @selector(saveClicked:)];
  [box addSubview: save];
  
  RELEASE(box);

  tabViewItem1 = [[NSTabViewItem alloc] initWithIdentifier: @"Activities"];
  [tabViewItem1 setLabel: _(@"Activities")];
  [tabViewItem1 setView: view];
  [tabView addTabViewItem: tabViewItem1];
  RELEASE(view);
  RELEASE(tabViewItem1);


  //
  // Our second tabview
  //
  messageColumn = [[NSTableColumn alloc] initWithIdentifier: @"Message"];
  [messageColumn setEditable: NO];
  [messageColumn setResizable: YES];
  [[messageColumn headerCell] setStringValue: _(@"Message")];
  [messageColumn setMinWidth: 115];
  [[messageColumn headerCell] setAlignment: NSLeftTextAlignment];
  
  dateColumn = [[NSTableColumn alloc] initWithIdentifier: @"Message Date"];
  [dateColumn setEditable: NO];
  [dateColumn setResizable: YES];
  [[dateColumn headerCell] setStringValue: _(@"Date")];
  [dateColumn setMinWidth: 140];
  [dateColumn setMaxWidth: 140];
  [[dateColumn headerCell] setAlignment: NSLeftTextAlignment];

  messagesScrollView = [[NSScrollView alloc] initWithFrame: NSMakeRect(5,35,470,100)];

  messagesTableView = [[NSTableView alloc] initWithFrame: [[messagesScrollView contentView] frame]];
  [messagesTableView setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];
  [messagesTableView setDrawsGrid: NO];
  [messagesTableView setAllowsColumnSelection: NO];
  [messagesTableView setAllowsColumnReordering: NO];
  [messagesTableView setAllowsColumnResizing: YES];
  [messagesTableView setAllowsEmptySelection: YES];
  [messagesTableView setAllowsMultipleSelection: NO];
  [messagesTableView addTableColumn: messageColumn];
  [messagesTableView addTableColumn: dateColumn];
  [messagesTableView setAutoresizesAllColumnsToFit: YES];
  [messagesTableView sizeLastColumnToFit];
  [messagesTableView setDataSource: [self windowController]];
  [messagesTableView setDelegate: [self windowController]];
  RELEASE(messageColumn);
  RELEASE(dateColumn);

  [messagesScrollView setDocumentView: messagesTableView];
  [messagesScrollView setHasHorizontalScroller: YES];
  [messagesScrollView setHasVerticalScroller: YES];
  [messagesScrollView setBorderType: NSBezelBorder];
  [messagesScrollView setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];

  tabViewItem2 = [[NSTabViewItem alloc] initWithIdentifier: @"Messages"];
  [tabViewItem2 setLabel: _(@"Messages")];
  [tabViewItem2 setView: messagesScrollView];
  [tabView addTabViewItem: tabViewItem2];
  RELEASE(tabViewItem2);
  
  //
  // We add our tabView
  //
  [[self contentView] addSubview: tabView];
  RELEASE(tabView);

  //
  // We set the window's minimum size
  //
  [self setMinSize: NSMakeSize(400,320)];
}

@end
